==========
socketscpi
==========


.. image:: https://img.shields.io/pypi/v/socketscpi.svg
        :target: https://pypi.python.org/pypi/socketscpi

.. image:: https://img.shields.io/travis/morgan-at-keysight/socketscpi.svg
        :target: https://travis-ci.org/morgan-at-keysight/socketscpi

.. image:: https://readthedocs.org/projects/socketscpi/badge/?version=latest
        :target: https://socketscpi.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




socketscpi provides a robust SCPI interface to electronic test and measurement equipment via raw socket protocol, removing the requirement for VISA and improving data transfer speed over VXI-11.


* Free software: GNU General Public License v3
* Documentation: https://socketscpi.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
